@@ -115,12 +115,12 @@ blast_to_phyloseq <- function(physeq,
     blast_tab_OK <- FALSE
   }
 
-  if (!keep_temporary_files) {
+  if (keep_temporary_files) {
+    message(paste0("Temporary files are located at ", tempdir()))
+  } else {
     unlink(paste0(tempdir(), "/", "blast_result.txt"))
     unlink(list.files(tempdir(), pattern = "dbase"))
     unlink(paste0(tempdir(), "/", "db.fasta"))
-  } else {
-    message(paste0("Temporary files are located at ", tempdir()))
   }
 
   if (!blast_tab_OK) {
@@ -292,12 +292,12 @@ blast_pq <- function(physeq,
     blast_tab_OK <- FALSE
   }
 
-  if (!keep_temporary_files) {
+  if (keep_temporary_files) {
+    message(paste0("Temporary files are located at ", tempdir()))
+  } else {
     unlink(paste0(tempdir(), "/", "blast_result.txt"))
     unlink(list.files(tempdir(), pattern = "dbase"))
     unlink(paste0(tempdir(), "/", "db.fasta"))
-  } else {
-    message(paste0("Temporary files are located at ", tempdir()))
   }
 
   if (!blast_tab_OK) {
@@ -542,12 +542,12 @@ blast_to_derep <- function(derep,
     blast_tab_OK <- FALSE
   }
 
-  if (!keep_temporary_files) {
+  if (keep_temporary_files) {
+    message(paste0("Temporary files are located at ", tempdir()))
+  } else {
     unlink(paste0(tempdir(), "/", "blast_result.txt"))
     unlink(list.files(tempdir(), pattern = "dbase"))
     unlink(paste0(tempdir(), "/", "db.fasta"))
-  } else {
-    message(paste0("Temporary files are located at ", tempdir()))
   }
 
   if (!blast_tab_OK) {
@@ -630,6 +630,8 @@ blast_to_derep <- function(derep,
 #' @inheritParams clean_pq
 #' @param fasta_for_db path to a fasta file to make the blast database
 #' @param silent (logical) If true, no message are printing.
+#' @param suffix (character) The suffix to name the new columns.
+#'   Set the suffix to "" in order to remove any suffix.
 #' @param ... Other arguments passed on to [blast_pq()] function.
 #' @return A new \code{\link[phyloseq]{phyloseq-class}} object with more information in tax_table based on a
 #'   blast on a given database
@@ -638,21 +640,27 @@ blast_to_derep <- function(derep,
 #'
 #' @author Adrien Taudière
 
-add_blast_info <- function(physeq, fasta_for_db, silent = FALSE, ...) {
+add_blast_info <- function(physeq, fasta_for_db, silent = FALSE, suffix = "blast_info", ...) {
   verify_pq(physeq)
   res_blast <- blast_pq(physeq,
     fasta_for_db = fasta_for_db,
-    unique_per_seq = TRUE, score_filter = FALSE, ...
+    unique_per_seq = TRUE,
+    score_filter = FALSE,
+    ...
   )
   new_physeq <- physeq
 
-  new_physeq@tax_table <- tax_table(cbind(
+  new_taxtab <- cbind(
     new_physeq@tax_table,
     as.matrix(res_blast[match(
       taxa_names(new_physeq),
       res_blast$`Query name`
     ), ])
-  ))
+  )
+
+  # colnames(new_taxtab) <- c(colnames(new_physeq@tax_table), paste0(colnames(physeq), suffix))
+
+  new_physeq@tax_table <- tax_table(new_taxtab)
 
   verify_pq(new_physeq)
   if (!silent) {
